seqtools.negate_absolute_value_of_sequence_elements_cyclically
==============================================================

.. autofunction:: abjad.tools.seqtools.negate_absolute_value_of_sequence_elements_cyclically
